@@ -50,7 +50,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_HORIZONTAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -132,7 +132,7 @@ composition_central_horizontal_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_MIDDLE_HORIZONTAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -212,7 +212,7 @@ composition_central_vertical_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 200);
     if (new_day_button->background)
@@ -292,7 +292,7 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -388,7 +388,7 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_VERTICAL_BACKGROUND);
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -506,7 +506,7 @@ composition_now(WDB *new_day_button, gint layout)
             gtk_widget_set_size_request(new_day_button->box, xoffset+140+1, 37+15+106);
             break;
     }
-    new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 /* Packing all to the box */
     if (new_day_button->background)
 //        gtk_layout_put((new_day_button->box), new_day_button->background, xoffset, 37+15);
@@ -590,7 +590,7 @@ next_station_preset_now(gint layout)
         case PRESET_NOW_PLUS_THREE_H:
         case PRESET_NOW_PLUS_SEVEN:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_HORIZONTAL);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
      //           gtk_layout_put((widget), background_town, 12+15, 0);
                 gtk_layout_put((widget), background_town, 12+15, 0);
@@ -599,7 +599,7 @@ next_station_preset_now(gint layout)
             break; 
         case PRESET_NOW_PLUS_TWO:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_TWO);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
          //       gtk_layout_put((widget), background_town, 12+15, 0);
                 gtk_layout_put((widget), background_town, 12+15, 0);
@@ -608,7 +608,7 @@ next_station_preset_now(gint layout)
             break;
         case PRESET_NOW_PLUS_THREE_V:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_THREE_V);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
 //                gtk_layout_put((widget), background_town, 0, 0);
                 gtk_layout_put((widget), background_town, 0, 0);
@@ -618,7 +618,7 @@ next_station_preset_now(gint layout)
         default:
         case PRESET_NOW:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN);
-            background_town = gtk_image_new_from_file (buffer);
+//            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
 //                gtk_layout_put((widget), background_town, 12+15, 0);
                 gtk_layout_put((widget), background_town, 12+15, 0);
@@ -776,7 +776,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
         }
-
+#if 0
         /* create day icon buffer */
         icon_buffer =
           gdk_pixbuf_new_from_file(buffer,
@@ -788,6 +788,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         }
         else
             new_day_button->wind = NULL;
+#endif
     }
   //  new_day_button->box  = gtk_fixed_new();
     new_day_button->box  = gtk_layout_new(NULL, NULL);
@@ -906,13 +907,15 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
                     wind_speed = wind_speed * 1.6;
                     break;
         }
+	/*
         if (wind_speed < STRONG_WIND)
-            new_day_button->wind = gtk_image_new_from_file (buffer);
+//            new_day_button->wind = gtk_image_new_from_file (buffer);
         else{
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
-           new_day_button->wind = gtk_image_new_from_file (buffer);
+//           new_day_button->wind = gtk_image_new_from_file (buffer);
         }
+	*/
     }
  //   new_day_button->box  = gtk_fixed_new();
     new_day_button->box  = gtk_layout_new(NULL, NULL);
